@@ -5,7 +5,7 @@ package Dist::Zilla::MintingProfile::Author::ETHER;
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Mint distributions like ETHER does
 
-our $VERSION = '0.153';
+our $VERSION = '0.154';
 
 use Moose;
 with 'Dist::Zilla::Role::MintingProfile' => { -version => '5.047' };
@@ -14,16 +14,13 @@ use Path::Tiny;
 use Carp;
 use namespace::autoclean;
 
-sub profile_dir
-{
+sub profile_dir {
     my ($self, $profile_name) = @_;
 
     die 'minting requires perl 5.014' unless "$]" >= 5.013002;
 
     my $dist_name = 'Dist-Zilla-PluginBundle-Author-ETHER';
-
     my $profile_dir = path(File::ShareDir::dist_dir($dist_name))->child('profiles', $profile_name);
-
     return $profile_dir if -d $profile_dir;
 
     confess "Can't find profile $profile_name via $self: it should be in $profile_dir";
@@ -43,7 +40,7 @@ Dist::Zilla::MintingProfile::Author::ETHER - Mint distributions like ETHER does
 
 =head1 VERSION
 
-version 0.153
+version 0.154
 
 =head1 SYNOPSIS
 
