@@ -5,7 +5,7 @@ package Pod::Weaver::PluginBundle::Author::ETHER;
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for pod woven by ETHER
 
-our $VERSION = '0.153';
+our $VERSION = '0.154';
 
 use namespace::autoclean -also => ['_exp'];
 use Pod::Weaver::Config::Assembler;
@@ -17,8 +17,7 @@ sub _exp { Pod::Weaver::Config::Assembler->expand_package($_[0]) }
 # This sub behaves somewhat like a Dist::Zilla pluginbundle's configure() -- it returns a list of strings or 1, 2
 # or 3-element arrayrefs containing plugin specifications. The goal is to make this look as close to what
 # weaver.ini looks like as possible.
-sub configure
-{
+sub configure {
     my $self = shift;
 
     # I wouldn't have to do this ugliness if I could have some configuration values passed in from weaver.ini or
@@ -107,24 +106,21 @@ SUPPORT
     );
 }
 
-sub mvp_bundle_config
-{
+sub mvp_bundle_config {
     my $self = shift || __PACKAGE__;
 
     return map $self->_expand_config($_), $self->configure;
 }
 
 my $prefix;
-sub _prefix
-{
+sub _prefix {
     my $self = shift;
     return $prefix if defined $prefix;
     ($prefix = (ref($self) || $self)) =~ s/^Pod::Weaver::PluginBundle:://;
     $prefix;
 }
 
-sub _expand_config
-{
+sub _expand_config {
     my ($self, $this_spec) = @_;
 
     die 'undefined config' if not $this_spec;
@@ -132,22 +128,18 @@ sub _expand_config
 
     my ($name, $class, $payload);
 
-    if (not ref $this_spec)
-    {
+    if (not ref $this_spec) {
         ($name, $class, $payload) = ($this_spec, _exp($this_spec), {});
     }
-    elsif (@$this_spec == 1)
-    {
+    elsif (@$this_spec == 1) {
         ($name, $class, $payload) = ($this_spec->[0], _exp($this_spec->[0]), {});
     }
-    elsif (@$this_spec == 2)
-    {
+    elsif (@$this_spec == 2) {
         $name = ref $this_spec->[1] ? $this_spec->[0] : $this_spec->[1];
         $class = _exp(ref $this_spec->[1] ? $this_spec->[0] : $this_spec->[0]);
         $payload = ref $this_spec->[1] ? $this_spec->[1] : {};
     }
-    else
-    {
+    else {
         ($name, $class, $payload) = ($this_spec->[1], _exp($this_spec->[0]), $this_spec->[2]);
     }
 
@@ -155,8 +147,7 @@ sub _expand_config
 
     # Region plugins have the custom plugin name moved to 'region_name' parameter,
     # because we don't want our bundle name to be part of the region name.
-    if ($class eq _exp('Region'))
-    {
+    if ($class eq _exp('Region')) {
         $name = $this_spec->[1];
         $payload = { region_name => $this_spec->[1], %$payload };
     }
@@ -185,7 +176,7 @@ Pod::Weaver::PluginBundle::Author::ETHER - A plugin bundle for pod woven by ETHE
 
 =head1 VERSION
 
-version 0.153
+version 0.154
 
 =head1 SYNOPSIS
 
